/* This file is part of the KDE project
   Copyright (C) 2002 Simon Hausmann <hausmann@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include "mainwindow.h"
#include "frontend.h"
#include "simplewindow.h"
#include "connection.h"
#include "commands.h"

#include <qtabwidget.h>

#include <kstatusbar.h>

#include <assert.h>

MainWindow::MainWindow( const IRC::ConnectionInfo &nfo, QWidget *parent, const char *name )
    : KMainWindow( parent, name )
{
    statusBar();

    IRC::Connection *connection = new IRC::Connection( this );

    m_frontend = new IRC::GenericFrontend<SimpleWindow>( connection, nfo, this );
    connect( m_frontend, SIGNAL( windowCreated( IRC::Window * ) ),
             this, SLOT( connectWindow( IRC::Window * ) ) );

    connection->connectToHost( nfo.host(), nfo.port() );

    m_view = new QTabWidget( this );
    setCentralWidget( m_view );

    connect( m_view, SIGNAL( currentChanged( QWidget * ) ),
             this, SLOT( currentTabChanged( QWidget * ) ) );

    m_view->setTabPosition( QTabWidget::Bottom );
}

MainWindow::~MainWindow()
{
}

void MainWindow::addTabView( QWidget *widget )
{
    m_view->insertTab( widget, widget->caption() );

    widget->installEventFilter( this );

    m_view->setCurrentPage( m_view->indexOf( widget ) );
}

bool MainWindow::eventFilter( QObject *obj, QEvent *ev )
{
    if ( ev->type() != QEvent::CaptionChange )
        return false;

    QWidget *widget = dynamic_cast<QWidget *>( obj );

    if ( !widget )
        return false;

    if ( m_view->currentPage() == widget ) 
        setPlainCaption( widget->caption() );

    return false;
}

void MainWindow::currentTabChanged( QWidget *tab )
{
    setPlainCaption( tab->caption() );
    tab->setFocus();
}

void MainWindow::connectWindow( IRC::Window *window )
{
    statusBar()->show();
    connect( window, SIGNAL( statusMessage( const QString & ) ),
             statusBar(), SLOT( message( const QString & ) ) );
}

#include "mainwindow.moc"

/* vim: et sw=4 ts=4
 */
