/* This file is part of the KDE project
   Copyright (C) 2002 Simon Hausmann <hausmann@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/
#ifndef STANDARDMESSAGEFILTERS_H
#define STANDARDMESSAGEFILTERS_H

#include "messagefilter.h"
#include "message.h"

namespace IRC
{

class ActionFilter : public NamedMessageFilter
{
    Q_OBJECT
public:
    ActionFilter( QObject *parent, const char *name = 0 )
        : NamedMessageFilter( "ME", parent, name ) {}

    virtual MessageFilter::Result filterMessage( Message &message, Window *window );
};

// this is actually a general pattern.... appending the current channel name if arguments
// are missing completely...
class PartFilter : public NamedMessageFilter
{
    Q_OBJECT
public:
    PartFilter( QObject *parent, const char *name = 0 )
        : NamedMessageFilter( PartMessage::name(), parent, name ) {}

    virtual MessageFilter::Result filterMessage( Message &message, Window *window );
};

class QueryFilter : public NamedMessageFilter
{
    Q_OBJECT
public:
    QueryFilter( QObject *parent, const char *name = 0 )
        : NamedMessageFilter( "QUERY", parent, name ) {}

    virtual MessageFilter::Result filterMessage( Message &message, Window *window );
};

class QuoteFilter : public NamedMessageFilter
{
    Q_OBJECT
public:
    QuoteFilter( QObject *parent, const char *name = 0 )
        : NamedMessageFilter( "QUOTE", parent, name ) {}

    virtual MessageFilter::Result filterMessage( Message &message, Window * /*window*/ );
};

class TopicFilter : public NamedMessageFilter
{
    Q_OBJECT
public:
    TopicFilter( QObject *parent, const char *name = 0 )
        : NamedMessageFilter( TopicMessage::name(), parent, name ) {}

    virtual MessageFilter::Result filterMessage( Message &message, Window *window );
};

}

#endif // STANDARDMESSAGEFILTERS_H
/* vim: et sw=4 ts=4
 */
